Coverage for src/paperap/resources/saved_views.py: 100%

1"""

2----------------------------------------------------------------------------

3

4 METADATA:

5

6 File: saved_views.py

7 Project: paperap

8 Created: 2025-03-04

9 Version: 0.0.5

10 Author: Jess Mann

11 Email: jess@jmann.me

12 Copyright (c) 2025 Jess Mann

13

14----------------------------------------------------------------------------

15

16 LAST MODIFIED:

17

18 2025-03-04 By Jess Mann

19

20"""

21

22 from __future__ import annotations

23

24 from paperap.models.saved_view import SavedView, SavedViewQuerySet

25 from paperap.resources.base import BaseResource, StandardResource

26

27

28 class SavedViewResource(StandardResource[SavedView, SavedViewQuerySet]):

29 """Resource for managing saved views."""

30

31 model_class = SavedView

32 name = "saved_views"